<?php 

/*
Plugin Name: EditorMonkey (Compatible)
Plugin URI: http://www.rajprasad.net/plugins/editormonkey/
Version: 2.4dev
Description: <p>Turns the normal WordPress textarea into a WYSIWYG editor using TinyMCE or FCKeditor. Also integrates spell checking into the editor interface using the FCK Speller Pages plugin and ieSpell. Supports custom dictionaries.</p><p>This is a restricted version which retains compatibility with PHP 4.3 and/or overly strict server configurations at the expense of some features. </p>
Author: Raj Prasad
Author URI: http://www.rajprasad.net/
*/

/*

*/

$editormmonkey_version = '2.4-compat';

	// Only functionalized to retain similarities to OO code for ease of maintanence
if (!function_exists('editormonkey')) {
	function editormonkey() {
	
		/*** OPTIONS **/
		// Add the default options for using EditorMonkey if they don't exist
		add_option('editormonkey_use', 'true', 'Automatically use the WYSIWYG interface');
		add_option('editormonkey_overrideusers', 'true', 'Force all users to use the plugin settings');
		add_option('editormonkey_disable_builtin', 'true', 'Automatically disable the built-in interface');
		add_option('editormonkey_interface', 'tinymce', 'The WYSIWYG interface to use when editing post or pages.');
		add_option('editormonkey_height', '250', 'Height, in pixels, of the WYSIWYG interface');
		add_option('editormonkey_lang', 'en', 'Dictionary to use for editor and spell checking');
		add_option('editormonkey_toolbar', 'WordPress', 'FCK toolbar buttons set');
		
		// File Browser settings
		add_option('editormonkey_upload',"false",'Allow uploading using the File Browser');
		add_option('editormonkey_upload_dir',"/YOURWEBSITE.COM/UserFiles/",'Directory for File Browser uploads');
		add_option('editormonkey_upload_rel',"/UserFiles/",'Directory for File Browser uploads');
		
		// Spell checking options
		add_option('editormonkey_aspell', 'aspell', 'Location of the aspell binary used for spell checking');
		add_option('editormonkey_spell','Jacuba','Spell checker to use.');
		add_option('editormonkey_spell_words',"WordPress\nEditorMonkey\nTinyMCE\nFCKeditor\nMozilla\nFirefox",'Personal dictionary words list.');
		
		// FCK options
		add_option('editormonkey_fck_skin', 'default', 'FCK graphical skin');
		
		// TinyMCE options
		add_option('editormonkey_mce_compress', 'false', 'Use gzip-compressed TinyMCE');
		add_option('editormonkey_mce_resize', 'false', 'Allow the editing area to be resized.');
		add_option('editormonkey_mce_plugins',array('emotions','paste','advimage','advlink','advhr','searchreplace','spellcheck','wordpress'), 'Plugins to load for TinyMCE');
		// Toolbar Editor (Options>EditorMonkey only)
		add_option('editormonkey_mce_toolbar', 'Simple', 'MCE Toolbars');
		add_option('editormonkey_mce_toolbar_data', 
			array('Basic' => array('false', 'false', 'bold,italic,underline,separator,numlist,bullist,separator,link,unlink,separator,emotions,separator,undo,redo,spellcheck'), 
				'Simple' => array('false','false', 'bold,italic,underline,separator,more,nextpage,separator,numlist,bullist,separator,link,unlink,separator,image,emotions,separator,undo,redo,spellcheck'),
				'Comments' => array('false','false','bold,italic,underline,separator,numlist,bullist,separator,emotions,separator,undo,redo,spellcheck'),
				'WordPress' => array('false','true','WordPress1,WordPress2,WordPress3')),
			'MCE Toolbars');
		
		// Styles Editor (editor css, content css)
		add_option('editormonkey_mce_css_editor', 'false', 'Custom Editor CSS');
		add_option('editormonkey_mce_css_content', 'false', 'Custom Content Area CSS');
		
		// Comment form options
		add_option('editormonkey_comm','false','Use WYSIWYG interface in comments form?');
		add_option('editormonkey_comm_size','200','Size of the editing area in the comments form');
		add_option('editormonkey_comm_if','fckeditor','WYSIWYG interface to use in comments form');
		add_option('editormonkey_comm_tb', 'Comments', 'Toolbar buttons set for comments form');
		add_option('editormonkey_comm_fck_skin', 'default', 'FCK graphical skin for comments form');
		
		/*** HOOKS **/
		// Plugin hook to the OPTIONS menu
		add_action('admin_menu', 'editormonkey_admin_menu');
		
		// Add actions to the various WP editing forms		
		add_action('admin_head','editormonkey_insert_interface');
		add_action('edit_form_advanced','editormonkey_load_interface');
		add_action('edit_page_form','editormonkey_load_interface');
		add_action('simple_edit_form','editormonkey_load_interface');

		// Add actions to the comment form
		add_action('wp_head', 'editormonkey_insert_comment_interface');	
		add_action('comment_form','editormonkey_load_comment_interface');
		
		// Add actions to Profile page so people can choose between interface options
		add_action('profile_personal_options','editormonkey_user_personalopts');
		add_action('personal_options_update','editormonkey_user_personalopts_update');
		
		// If the admin has chosen to disable WP from loading the built-in editor in EditorMonkey
		// plugin page, but enabled WP to do so from the Options>Writing page, disable it so that
		// it doesn't interfere with EditorMonkey
		if (get_option('editormonkey_disable_builtin') == 'true')
			update_option('rich_editing', 'false');
		
		
		// If this is the plugins page, show the plugin options
		if (is_plugin_page()) {
			editormonkey_plugin_panel();
		}
	}
}
	
	
if (!function_exists('editormonkey_admin_menu')) {
	function editormonkey_admin_menu () {
		if (function_exists('add_options_page')) {
			add_options_page('EditorMonkey', 'EditorMonkey', 8, basename(__FILE__));
		}
	}
}

	/**
		Inserts javascript for the interfaces
	*/

if (!function_exists('editormonkey_insert_interface')) {
	function editormonkey_insert_interface () {
		global $current_user,  $action;
		
		// Comment form in Admin mode
		if (($action=='editcomment') && (get_option('editormonkey_overrideusers') == 'true')) {
			add_action('admin_footer','editormonkey_load_interface');
		}
			
		// Check to make sure users prefs are set in case they are needed
		if(get_user_option('em_user_userprefset') != 'true') {
			update_user_option( $current_user->id, 'em_user_userprefset', 'true', true);
			
			update_user_option( $current_user->id, 'em_user_use', get_option('editormonkey_use'), true);
			update_user_option( $current_user->id, 'em_user_height', get_option('editormonkey_height'), true);
			update_user_option( $current_user->id, 'em_user_lang', get_option('editormonkey_lang'), true);
			update_user_option( $current_user->id, 'em_user_interface', get_option('editormonkey_interface'), true);
			update_user_option( $current_user->id, 'em_user_toolbar', get_option('editormonkey_toolbar'), true);
			update_user_option( $current_user->id, 'em_user_fck_skin', get_option('editormonkey_fck_skin'), true);
			update_user_option( $current_user->id, 'em_user_spell_words', get_option('editormonkey_spell_words'), true);
		}
		
		// Retrieve the options from plugin or user as appropriate
		if ( get_option('editormonkey_overrideusers') == 'true' ) {
			$em_use = get_option('editormonkey_use');
			$em_interface = get_option('editormonkey_interface');
		} else {
			$em_use = get_user_option('em_user_use');
			$em_interface = get_user_option('em_user_interface');
		} 
		
		// Disable built-in editor if we are using EditorMonkey
		if ($em_use == 'true')
			update_user_option( $current_user->id, 'rich_editing', 'false', true);
		
		?>
		<style type="text/css">
				/* hide the quick tags */
				#quicktags { display: none; }
				
				/* toggle dbx images */
				a.dbx-toggle, a.dbx-toggle:visited {
					display:block;
					overflow: hidden;
					background-image: url( images/toggle.gif );
					position: absolute;
					top: 0px;
					right: 0px;
					background-repeat: no-repeat;
					border: 0px;
					margin: 0px;
					padding: 0px;
				}
								
				a.dbx-toggle, #moremeta a.dbx-toggle-open:visited {
					height: 25px;
					width: 27px;
					background-position: 0 0px;
				}
				
				a.dbx-toggle-open, #moremeta a.dbx-toggle-open:visited {
					height: 25px;
					width: 27px;
					background-position: 0 -25px;
				}
				
				#grabit {
					width: 100%;
				}
				
				
			</style>
		<?php
		
		if ( $em_use == 'true' ) {
			switch ($em_interface) {
			case 'tinymce' :
				editormonkey_insert_TinyMCE();
				break;
			case 'fckeditor' :
				// fall through to default
			default :
				editormonkey_insert_FCKeditor();
				break;
			}
			?>
			
			<script type="text/javascript" src="../wp-includes/js/dbx.js"></script>
			<script type="text/javascript" >
				var em_manager = new dbxManager('editormonkey');
			</script>
			<script type="text/javascript" >
			addLoadEvent( function() {
				var emmeta = new dbxGroup(
					'emgrabit', 	// container ID [/-_a-zA-Z0-9/]
					'vertical', 	// orientation ['vertical'|'horizontal']
					'10', 			// drag threshold ['n' pixels]
					'yes',			// restrict drag movement to container axis ['yes'|'no']
					'10', 			// animate re-ordering [frames per transition, or '0' for no effect]
					'yes', 			// include open/close toggle buttons ['yes'|'no']
					'closed', 		// default state ['open'|'closed']
					'open', 		// word for "open", as in "open this box"
					'close', 		// word for "close", as in "close this box"
					'click-down and drag to move this box', // sentence for "move this box" by mouse
					'click to %toggle% this box', // pattern-match sentence for "(open|close) this box" by mouse
					'use the arrow keys to move this box', // sentence for "move this box" by keyboard
					', or press the enter key to %toggle% it',  // pattern-match sentence-fragment for "(open|close) this box" by keyboard
					'%mytitle%  [%dbxtitle%]' // pattern-match syntax for title-attribute conflicts
					);
				});
			</script>
			
			<?php
		}
	}
}
	
	
	/**
		Inserts the appropriate interface for the comment form into the header
	*/
if (!function_exists('editormonkey_insert_comment_interface')) {
	function editormonkey_insert_comment_interface() {	
		if (get_option('editormonkey_comm') == 'true') { 		
			$em_interface = get_option('editormonkey_comm_if');
			switch ($em_interface) {
			case 'tinymce' :
				editormonkey_insert_TinyMCE();
				break;
			case 'fckeditor' :
				// Fall through to default
			default :
				editormonkey_insert_FCKeditor();
				break;
			}
		}
	}
}
	
		
	/**
		Helper functions to reduce clutter in the bigger functions and reduce # of times
		I repeat code that might have to be changed later
	*/
if (!function_exists('editormonkey_insert_FCKeditor')) {
	function editormonkey_insert_FCKeditor() {
		?><script type="text/javascript" src="<?php echo get_settings('siteurl'); ?>/wp-content/plugins/editormonkey/fckeditor/fckeditor.js"></script><?php
	}
}
if (!function_exists('editormonkey_insert_TinyMCE')) {
	function editormonkey_insert_TinyMCE() {
		if ( get_option('editormonkey_mce_compress')  == 'true' ) {
		?><script type="text/javascript" src="<?php echo get_settings('siteurl'); ?>/wp-content/plugins/editormonkey/tinymce/tiny_mce_gzip.php"></script><?php
		} else {
		?><script type="text/javascript" src="<?php echo get_settings('siteurl'); ?>/wp-content/plugins/editormonkey/tinymce/tiny_mce.js"></script><?php
		}
	}
}
	
	
	/**
		Calls the interface-specific loading function
	*/
if (!function_exists('editormonkey_load_interface')) {
	function editormonkey_load_interface () {
		if ( get_option('editormonkey_overrideusers') == 'true' ) {
			$em_use = get_option('editormonkey_use');
			$em_interface = get_option('editormonkey_interface');
			$em_height = get_option('editormonkey_height');
			$em_lang = get_option('editormonkey_lang');
			$em_spellcheck = get_option('editormonkey_spell');
			$em_toolbar = get_option('editormonkey_toolbar');
			$em_skin = get_option('editormonkey_fck_skin');
		} else {
			$em_use = get_user_option('em_user_use');
			$em_interface = get_user_option('em_user_interface');
			$em_height = get_user_option('em_user_height');
			$em_lang = get_user_option('em_user_lang');
			$em_toolbar = get_user_option('em_user_toolbar');
			$em_skin = get_user_option('em_user_fck_skin');
		}
		
		$em_spellcheck = get_option('editormonkey_spell');
		$em_upload = get_option('editormonkey_upload');
	
		if ($em_use == 'true') { 
			switch ($em_interface) {
			case 'tinymce' :
				editormonkey_load_TinyMCE('content', $em_height, $em_lang, $em_toolbar, $em_spellcheck, $em_upload);
				break;
			case 'fckeditor' :
				// fall through to default
			default :
				editormonkey_load_FCKeditor( 'content', $em_height, $em_lang, $em_toolbar, $em_skin, $em_spellcheck, $em_upload);
				break;
			}
		}
	}
}

	
	/**
		Loads the appropriate interface for the comment form
	*/
if (!function_exists('editormonkey_load_comment_interface')) {
	function editormonkey_load_comment_interface( ) {
		if (get_option('editormonkey_comm') == 'true') {

			$em_lang = get_option('editormonkey_lang');
			$em_spellcheck = get_option('editormonkey_spell');
			$em_interface = get_option('editormonkey_comm_if');
			$em_height = get_option('editormonkey_comm_size');
			$em_toolbar = get_option('editormonkey_comm_tb');
			$em_skin = get_option('editormonkey_comm_fck_skin');
			
			switch ($em_interface) {
				case 'tinymce' :
					editormonkey_load_TinyMCE('comment', $em_height, $em_lang, $em_toolbar, $em_spellcheck, false );
					break;
				case 'fckeditor' :
					// fall through to default
				default :
					editormonkey_load_FCKeditor( 'comment', $em_height, $em_lang, $em_toolbar, $em_skin, $em_spellcheck, false );
					break;
			}
		}
	}
}

	
	/** 
		Loads the FCKeditor interface
	*/
if (!function_exists('editormonkey_load_FCKeditor')) {
	function editormonkey_load_FCKeditor ( $em_textarea, $em_height, $em_lang, $em_toolbar, $em_skin, $em_spellcheck, $em_upload ) {
	if (($em_spellcheck == 'Jacuba') || ($em_spellcheck == 'phpSpell')) {$em_spellcheck='';}
?>
<script type="text/javascript">
// Doesn't wait until loading b/c sometimes Firefox doesn't ever finish loading the page.
// Instead...we wait for the image below this to load	
function initFCK() {
	var oFCKeditor = new FCKeditor( '<?php echo $em_textarea; ?>' ) ;
	oFCKeditor.Config["CustomConfigurationsPath"] = "<?php echo get_settings('siteurl'); ?>/wp-content/plugins/editormonkey/emfckconfig.js.php"  ;
	
	// Basic stuff
	oFCKeditor.BasePath = "<?php echo get_settings('siteurl'); ?>/wp-content/plugins/editormonkey/fckeditor/";
	oFCKeditor.Config[ "BaseHref"] = "<?php echo get_settings('siteurl'); ?>" ;
	oFCKeditor.Height = "<?php echo $em_height; ?>";
	
	// Interface
	oFCKeditor.ToolbarSet = "<?php echo $em_toolbar; ?>";
	oFCKeditor.Config[ "SkinPath"] = oFCKeditor.BasePath + 'editor/skins/<?php echo $em_skin; ?>/';
	
	// Language and spellchecking
	oFCKeditor.Config[ "DefaultLanguage" ] = "<?php echo $em_lang; ?>";
	oFCKeditor.Config[ "SpellChecker" ] = "<?php echo $em_spellcheck; ?>";
	
	// Uploads 
	<?php if ($em_textarea == 'comment') { ?>
	oFCKeditor.Config.LinkBrowser = false;
	oFCKeditor.Config.ImageBrowser = false;
	oFCKeditor.Config.FlashBrowser = false;
	<?php } ?>
	
	oFCKeditor.ReplaceTextarea() ;
}
</script>
<img src="<?php echo get_settings('siteurl'); ?>/wp-content/plugins/editormonkey/spacer.gif" onload="initFCK();" />
<?php
	}
}

	
	/** 
		Loads the TinyMCE interface
	*/
if (!function_exists('editormonkey_load_TinyMCE')) {
	function editormonkey_load_TinyMCE ( $em_textarea, $em_height, $em_lang, $em_toolbar, $em_spellcheck, $em_upload ) {	
		// Convert Spell Check variable...
		switch ($em_spellcheck) {
		case 'SpellerPages' :
			$em_spellcheck='spellerpages'; break;
		case 'ieSpell' : 
			$em_spellcheck='iespell'; break;
		case 'Jacuba' :
			$em_spellcheck='jacuba'; break;
		default :
			$em_spellcheck='';
		}
		
		// Load the plugins we need, only load one of the spell check plugins
		$plugins = get_option('editormonkey_mce_plugins');
		if (NULL !== $plugins) {
			$em_plugins = "'";
			$num_plugins = count($plugins);
			for ( $i = 0; ($i < $num_plugins) && is_array($plugins); $i++ ) {
				$plugin = array_pop($plugins);
				if ($plugin == 'spellcheck') {
					$plugin = $em_spellcheck;
				} 
				$em_plugins = $em_plugins . "$plugin,";
			}
			$em_plugins = $em_plugins . "'";
		} else {
			$em_plugins = "''";
		}
		
		// Load Toolbars here so we don't clutter the javascript output
		switch ($em_toolbar) {
			case 'WordPress': 
				$em_toolbar = 'WordPress1,WordPress2,WordPress3';
				$em_toolbar_content = "theme_advanced_container_WordPress1 : 'undo,redo,separator,selectall,cut,copy,paste,separator,pastetext,pasteword,separator,search,replace,separator,code, cleanup,separator,visualaid,fullscreen,separator,help,$em_spellcheck',\n" .
	"\ttheme_advanced_container_WordPress2 : 'link,unlink,anchor,separator,image,separator,more,nextpage,separator,advhr,charmap,emotions,separator,tablecontrols',\n" .
	"\ttheme_advanced_container_WordPress3 : 'formatselect,separator,fontsizeselect,separator,bold,italic,underline,strikethrough,sub,sup,separator,justifyleft,justifyright,justifycenter,justifyfull,separator,bullist,numlist,indent,outdent,separator,forecolor,backcolor,separator,removeformat',";
				break;
			case 'Simple' :
				$em_toolbar_content = "theme_advanced_container_Simple : 'bold,italic,underline,separator,fontsizeselect,forecolor,numlist,bullist,separator,link,unlink,separator,image,emotions,separator,undo,redo,$em_spellcheck',";
				break;
			case 'Comments' :
				$em_toolbar_content = "theme_advanced_container_Comments :  'bold,italic,underline,separator,numlist,bullist,separator,emotions,separator,undo,redo,$em_spellcheck',";
				break;
			case 'Basic' :
				$em_toolbar_content = "theme_advanced_container_Basic : 'bold,italic,underline,separator,numlist,bullist,separator,link,unlink,separator,emotions,separator,undo,redo,$em_spellcheck',";
			default:
				// Retrieve Custom Toolbars here
				break;
		}
		
		//include_once( dirname(__FILE__).'/editormonkey/extendelements.php'); 
		// Comment form overrides
		if ( $em_textarea == 'comment' ) {
			$em_resize = 'false';
		}
		// resize
		// upload
?>
<style type="text/css">
.wpTinyMCE a { border-bottom:none;}
</style>
<script language="javascript" type="text/javascript">
// Check for preview window (true/false determined by php code)
if ( window == top || <?php echo get_option('editormonkey_interface')!='tinymce' ? 'true' : 'false';?>) {
tinyMCE.init({
	mode : "exact",
	elements : "<?php echo $em_textarea; ?>",
	language : "<?php echo $em_lang; ?>",
	height: "<?php echo $em_height; ?>",
	
	plugins : <?php echo $em_plugins; ?>,
	<?php if ($em_upload == 'true') echo 'file_browser_callback : "fileBrowserCallBack",'; ?>

	theme : "advanced",
	theme_advanced_layout_manager : "RowLayout",
	theme_advanced_containers_default_class : "wpTinyMCE",
	theme_advanced_containers_default_align : "left",
	theme_advanced_resizing : <?php echo get_option('editormonkey_mce_resize'); ?>,	
	
	theme_advanced_containers : "<?php echo $em_toolbar; ?>,mceEditor<?php echo ($em_textarea != 'comment') ? ',mceElementpath' : ''; ?>",
	<?php echo $em_toolbar_content; ?>
	
	remove_linebreaks : false,
	valid_elements : <?php if (get_option('editormonkey_mce_extended') == 'true') {include (dirname(__FILE__).DIRECTORY_SEPARATOR.'editormonkey'.DIRECTORY_SEPARATOR.'valid_elements.inc');	} else echo '"-a[id|href|title|rel|target],-strong/b,-em/i,-strike,-del,-u,p[class|align|dir],-ol,-ul,-li,br,img[class|src|alt|title|width|height|align],-sub,-sup,-blockquote[dir],-table[border|cellspacing|cellpadding|width|height|class|align|dir],thead[class|rowspan|width|height|align|valign|dir],tr[class|rowspan|width|height|align|valign|dir],th[dir|class|colspan|rowspan|width|height|align|valign|scope],td[dir|class|colspan|rowspan|width|height|align|valign],-div[dir|class|align],-span[class|align],-pre[class],-code[class],-address,-h1[class|align|dir],-h2[class|align|dir],-h3[class|align|dir],-h4[class|align|dir],-h5[class|align|dir],-h6[class|align|dir],hr[class|width|size|noshade]"'; ?>
	
});}

	function fileBrowserCallBack(field_name, url, type, win) {
			tinyfck_field = field_name;
			tinyfck = win;
			window.open("<?php echo get_settings('siteurl'); ?>/wp-content/plugins/editormonkey/tinymce/filemanager/browser.html?Connector=connectors/php/connector.php", "tinyfck", "modal,width=600,height=400");
	}
</script>
<?php
	}
}

	
	/** 
		Displays the EditorMonkey configuration form
	*/
if (!function_exists('editormonkey_plugin_panel')) {
	function editormonkey_plugin_panel () {
		$path = get_option('siteurl') . '/wp-admin/admin.php?page=editormonkey-compat.php'; // Form Action URI
		
		// Update preferences and other actions
		if ($_POST['editormonkey_action']=='Submit Changes') {
			update_option('editormonkey_use', $_POST['em_use']);
			update_option('editormonkey_overrideusers', $_POST['em_override']);
			update_option('editormonkey_interface', $_POST['em_interface']);
			update_option('editormonkey_height', $_POST['em_height']);
			update_option('editormonkey_toolbar', $_POST['em_fck_toolbar']);
					
			update_option('editormonkey_upload', 'false');
			
			update_option('editormonkey_lang', $_POST['em_lang']);
			update_option('editormonkey_spell', $_POST['em_spell']);
			
			update_option('editormonkey_comm', $_POST['em_comments']);
			update_option('editormonkey_comm_size', $_POST['em_comments_height']);
			update_option('editormonkey_comm_if', $_POST['em_comments_interface']);
			update_option('editormonkey_comm_tb', $_POST['em_comments_toolbar']);
			update_option('editormonkey_comm_fck_skin', $_POST['em_comments_fckskin']);	
			
			update_option('editormonkey_fck_skin', $_POST['em_fck_skin']);
			
			update_option('editormonkey_mce_compress', 'false');
			if ( !isset( $_POST['em_mce_resize'] ) ) {
				$_POST['em_mce_resize'] = 'false';
			}
			update_option('editormonkey_mce_resize', $_POST['em_mce_resize']);
				
			// Disable the default WYSIWYG?
			if ( !isset( $_POST['em_disable_builtin'] ) )
				$_POST['em_disable_builtin'] = 'false';
			else
				update_option('rich_editing', 'false');
			update_option('editormonkey_disable_builtin',$_POST['em_disable_builtin']);
					
			$msg_result = 'EditorMonkey settings updated at ' . date('h:i:s a') . '.';
		}
		
		
		// Display status update and panel here
		if ($msg_result) {
		?>
		<div class="updated"><p><?php echo $msg_result; ?></p></div><?php
		}
		
		// Display configuration form
		?>
		<div class="wrap">		
		<h2>EditorMonkey Configuration</h2>

		<form name="editormonkey_config" method="post" action="<?php echo $path ?>">
			<p>
			<input name="editormonkey_action" type="submit" id="editor_action" value="Submit Changes">
			<input type="reset" name="Reset" value="Reset">	
			</p>

		<div id="emgrabit" class="dbx-group">
		
		<fieldset id="em_systemsettings" class="dbx-box">
		<h3 class="dbx-handle">System Settings</h3>
		<div class="dbx-content"> 
			<br />
			<div>
				<input name="em_use" type="checkbox" id="em_use" value="true" style="display:inline" <?php checked('true', get_option('editormonkey_use')); ?> />
				<strong>Automatically use the EditorMonkey interface?</strong>
				<p>This will automatically load the EditorMonkey WYSIWYG editor interface selected below, unless the user (in WP2 only) chooses otherwise.</p>
			</div>

			<div>
				<input name="em_disable_builtin" id="em_disable_builtin" type="checkbox" value="true" style="display:inline" <?php checked('true', get_option('editormonkey_disable_builtin')); ?> />	
				<strong>Automatically disable WordPress from loading the built-in WYSIWYG editor by default?</strong> 
				<p>WordPress admins can choose to have the built-in WYSIWYG editor loaded by default from the Options>Writing panel. The built-in WYSIWYG editor will interfere with EditorMonkey's editor and could crash the browser, so EditorMonkey will disable it by default unless you decide otherwise.</p>
			</div>
	  
			<div>
				<input name="em_override" id="em_override" type="checkbox" value="true" style="display:inline" <?php checked('true', get_option('editormonkey_overrideusers')); ?> />	  
				<strong>Override user preferences?</strong> 
				<p>This will override all user preferences with the settings for the plugin set on this page. User preferences will not be changed.</p>
			</div>
			<br />
		</div>
		</fieldset>


		<fieldset id="em_basicsettings" class="dbx-box">
		<h3 class="dbx-handle">Basic Interface Settings</h3>
		<div class="dbx-content">
			<br />
			<div>
				<strong>Default WYSIWYG interface: </strong> 
				<select name="em_interface" id="em_interface">
					<option value="fckeditor" <?php if(get_option('editormonkey_interface')=='fckeditor') echo 'selected="selected"'; ?>>FCKEditor &nbsp;</option>
					<option value="tinymce" <?php if(get_option('editormonkey_interface')=='tinymce') echo 'selected="selected"'; ?>>TinyMCE &nbsp;</option>
				</select>
				<p>FCKeditor offers more advanced features, but is not integrated with WordPress. TinyMCE offers a simpler interface and fewer features, but is integrated with WordPress.</p>
			</div>
	  
			<div>
			<strong>Default editing area height: </strong> 
			<input type="text" name="em_height" id="em_height" value="<?php echo get_option('editormonkey_height'); ?>"/>
			<p>The size of the editing area should be large enough to include the editing area AND the toolbars.</p>
			</div>
			
			<div>
				<strong>Default language: </strong> 
				<?php language_selection(get_option('editormonkey_lang')); ?>
				<p>This language will be used by the editor to display tooltips, prompts, and labels. The spell checker will use the selected language's dictionary when spellchecking the document. Not all languages are supported by all the editors, and not all languages are supported by the spell checker.</p>
			</div>
			
			<div>			
				<strong>Editor toolbar button set:</strong> 
				<select name="em_fck_toolbar" id="em_fck_toolbar">
					<option value="WordPress" <?php if(get_option('editormonkey_toolbar')=='WordPress') echo 'selected="selected"'; ?>>WordPress Controls &nbsp;</option>
					<option value="Basic" <?php if(get_option('editormonkey_toolbar')=='Basic') echo 'selected="selected"'; ?>>Basic Controls &nbsp;</option>
					<option value="Simple" <?php if(get_option('editormonkey_toolbar')=='Simple') echo 'selected="selected"'; ?>>Simple Controls &nbsp;</option>
				</select>
				<p>The Basic toolbar provides a minimalistic set of buttons. The Simple toolbar most closely approximates the default WordPress toolbar. The default WordPress toolbar contains buttons for all webpage elements that are likely to be used in a WordPress post or page.</p>
			</div>
			<br />
		</div>
		</fieldset>
	
	
		<fieldset id="em_filebrowsersettings" class="dbx-box">
		<h3 class="dbx-handle">File Browser/Uploader Settings</h3>
		<div class="dbx-content">
			<br />
			<div>		  		  
				<input name="em_upload" id="em_upload" type="checkbox" value="true" style="display:inline" disabled /> 
				<strong>Allow uploads and file browsing?</strong> 
				<p>Uploads cannot be enabled in the restricted version of EditorMonkey.</p>
			</div>
			<br />
		</div>
		</fieldset>
	
		  
		<fieldset id="em_spellsettings" class="dbx-box">
		<h3 class="dbx-handle">Spell Checker Settings</h3>
		<div class="dbx-content">
			<br />
			<div>
				<p>The <strong>Jacuba</strong> spellchecking service is offered by Jacuba for free. It requires Internet Explorer, Mozilla, or Firefox. <strong>ieSpell</strong> runs client-side (in the user's browser), but has to be installed separately and only works in Internet Explorer. Firefox users may <strong>Spellbound</strong>, which automatically integrates itself into the ditor. Download Spellbound <a href='http://spellbound.sourceforge.net/download'>here</a> or <a href='http://exchangecode.com/spellbound/downloads/spellbound-dev_20060108.xpi'>here</a>.</p>
				<p>
				<strong>Spell Checker: </strong>
				<select name="em_spell" id="em_spell" onchange="spellOpts(this.value)">
					<option value="none" <?php if(get_option('editormonkey_spell')=='none') echo 'selected="selected"'; ?>>No Spell Checker &nbsp;</option>
					<option value="Jacuba" <?php if(get_option('editormonkey_spell')=='Jacuba') echo 'selected="selected"'; ?>>Jacuba &nbsp;</option>
					<option value="ieSpell" <?php if(get_option('editormonkey_spell')=='ieSpell') echo 'selected="selected"'; ?>>ieSpell &nbsp;</option>
				</select>
				</p>
			</div>
			<br />
		</div>
		</fieldset>
		  
		<fieldset id="em_fcksettings" class="dbx-box">
		<h3 class="dbx-handle">FCKeditor Settings</h3>
		<div class="dbx-content">
			<br />
			<div>
				<strong>Graphical skin: </strong>
				<select name="em_fck_skin" id="em_fck_skin">
					<option value="default" <?php if(get_option('editormonkey_fck_skin')=='default') echo 'selected="selected"'; ?>>Default &nbsp;</option>
					<option value="office2003" <?php if(get_option('editormonkey_fck_skin')=='office2003') echo 'selected="selected"'; ?>>Office 2003 &nbsp;</option>
					<option value="silver" <?php if(get_option('editormonkey_fck_skin')=='silver') echo 'selected="selected"'; ?>>Silver &nbsp;</option>
				</select>
				<p>The graphical skin does not provide any functionality. It simly changes the look of the FCKeditor toolbar and buttons.</p>
			</div>
			<br />
		</div>
		</fieldset>
		  
		<fieldset id="em_mcesettings" class="dbx-box">
		<h3 class="dbx-handle">TinyMCE Settings</h3>
		<div class="dbx-content">
			<br />
			<div>		  		  
				<input name="em_mce_compress" id="em_mce_compress" type="checkbox" value="true" style="display:inline" disabled /> 
				<strong>Use Cached?</strong> 
				<p>TinyMCE will not be cached by the restricted version of EditorMonkey.</p>
			</div>
			
			<div>		  		  
				<input name="em_mce_extended" id="em_mce_extended" type="checkbox" value="true" style="display:inline" disabled /> 
				<strong>Use Custom Valid HTML Elements List?</strong> 
				<p>TinyMCE cannot use the custom elements list in the restricted version of EditorMonkey.</p>
			</div>
			
			<div>		  		  
				<input name="em_mce_resize" id="em_mce_resize" type="checkbox" value="true" style="display:inline" <?php checked('true', get_option('editormonkey_mce_resize')); ?> /> 
				<strong>Allow resizing?</strong> 
				<p>If this is selected, all users will be able to resize the editing area graphically (ie, Windows style) when they are editing posts.</p>
			</div>
			
			<div>
			<strong>Plugins:</strong> 
			<p>It is not possible to change the set of TinyMCE plugins when using the restricted version of EditorMonkey.</p>
			</div>
			
			<br />
		</div>
		</fieldset>
		
		<fieldset id="em_commentsettings" class="dbx-box">
		<h3 class="dbx-handle">Comment Form Settings</h3>
		<div class="dbx-content">
			<br />
			<div>		  		  
				<input name="em_comments" id="em_comments" type="checkbox" value="true" style="display:inline" <?php checked('true', get_option('editormonkey_comm')); ?> /> 
				<strong>Use WYSIWYG comments form? </strong> 
				<p>This will replace the plain-text comments form with a simple WYSIWYG form.</p>
			</div>
		  
			<div>
				<strong>Comments form interface: </strong> 
				<select name="em_comments_interface" id="em_comments_interface">
					<option value="fckeditor" <?php if(get_option('editormonkey_comm_if')=='fckeditor') echo 'selected="selected"'; ?>>FCKEditor &nbsp;</option>
					<option value="tinymce" <?php if(get_option('editormonkey_comm_if')=='tinymce') echo 'selected="selected"'; ?>>TinyMCE &nbsp;</option>
				</select>
				<p>The interface to use in the comments form.</p>
			</div>

			<div>
				<strong>Toolbar button set: </strong> 
				<select name="em_comments_toolbar" id="em_comments_toolbar">
					<option value="Comments" <?php if(get_option('editormonkey_comm_fck_tb')=='Comments') echo 'selected="selected"'; ?>>Comments &nbsp;</option>
					<option value="Basic" <?php if(get_option('editormonkey_comm_tb')=='Basic') echo 'selected="selected"'; ?>>Basic Controls &nbsp;</option>
					<option value="Simple" <?php if(get_option('editormonkey_comm_tb')=='Simple') echo 'selected="selected"'; ?>>Simple Controls &nbsp;</option>
				</select>
				<p>Basic button sets appropriate for a comment form. Both TinyMCE and FCKeditor will use the same set of buttons for the comment form.</p>
			</div>
		  
		  	<div>
				<strong>Comments form editing area size </strong> 
				<input type="text" name="em_comments_height" id="em_comments_height" value="<?php echo get_option('editormonkey_comm_size'); ?>"/>
				<p>The size of the comment editing area, in pixels.</p>
			</div>
		
			<div>
				<strong>FCKeditor graphical skin: </strong> 
				<select name="em_comments_fckskin" id="em_comments_fckskin">
					<option value="default" <?php if(get_option('editormonkey_comm_fck_skin')=='default') echo 'selected="selected"'; ?>>Default &nbsp;</option>
					<option value="office2003" <?php if(get_option('editormonkey_comm_fck_skin')=='office2003') echo 'selected="selected"'; ?>>Office 2003 &nbsp;</option>
					<option value="silver" <?php if(get_option('editormonkey_comm_fck_skin')=='silver') echo 'selected="selected"'; ?>>Silver &nbsp;</option>
				</select>
				<p>Just a little something to make that comment form look extra nice.</p>
			</div>
		</div>
		</fieldset>
		
		</div>
		  	
			<p>
			<input name="editormonkey_action" type="submit" id="editor_action" value="Submit Changes">
			<input type="reset" name="Reset" value="Reset">			
			</p>
		
		</form>
		</fieldset>
		</div>
		<?php
	}
}

	
	/** 
		Adds EditorMonkey to the Personal Options section of the (user) Profile page
	*/
if (!function_exists('editormonkey_user_personalopts')) {
	function editormonkey_user_personalopts() {
		global $current_user;
		
		// NO PERSONAL DICTIONARY SUPPORT!!!
		
		?>
		<hr noshade />
		<h3>EditorMonkey Preferences</h3>
		<p class="desc">EditorMonkey replaces the WordPress visual rich editor with a more advanced WYSIWYG editor using FCKeditor or TinyMCE.</p>
			<?php
			if ( get_option('editormonkey_overrideusers') == 'true' ) {
				?><p class="error">The plugin is currently set to override user preferences. You may make and save changes to your EditorMonkey preferences but they will not take affect. Please contact your website administrator if you wish to use your personal preferences.</p><?php
			}
			?>
		
		<div id="emgrabit" class="dbx-group">
		
		<div id="em_basicsettings" class="dbx-box dbx-box-open">
		<h3 class="dbx-handle">Basic Settings</h3>
		<div class="dbx-content">
			<div>		  		  
				<p><input name="em_use" type="checkbox" id="em_use" value="true" style="display:inline" <?php checked('true', get_user_option('em_user_use')); ?> />
					<label for="em_use"><strong>Use the EditorMonkey WYSIWYG editor instead of the WordPress visual rich editor.</strong></label>
				</p>
			</div>
		
			<div>
			<p><label for="em_interface"><strong>Editor interface to use: </strong></label> 
				<select name="em_interface" id="em_interface">
					<option value="fckeditor" <?php selected('fckeditor', get_user_option('em_user_interface'));?>/>FCKEditor &nbsp;</option>
					<option value="tinymce" <?php selected('tinymce', get_user_option('em_user_interface'));?>/>TinyMCE &nbsp;</option>
				</select></p>
			</div>
			
			<div>
			<p><label for="em_height"><strong>Editing area height, in pixels: </strong></label> 
				<input name="em_height" type="text" id="em_height" value="<?php echo get_user_option('em_user_height'); ?>" />
			</p>
			</div>
				
			<div>
			<p><label for="em_lang"><strong>Editor language: </strong></label> 
				<?php language_selection(get_user_option('em_user_lang')); ?></p>
			</div>
			
			<div>
			<p><label for="em_fck_toolbar"><strong>Toolbar button set: </strong></label>
				<select name="em_fck_toolbar" id="em_fck_toolbar">
					<option value="WordPress" <?php selected('WordPress', get_user_option('editormonkey_toolbar'));?>/>WordPress &nbsp;</option>
					<option value="Basic"  <?php selected('Basic', get_user_option('em_user_toolbar'));?>/>Basic Controls &nbsp;</option>
					<option value="Simple"  <?php selected('Simple', get_user_option('em_user_toolbar'));?>/>Simple Controls &nbsp;</option>
				</select>
			  </p>
			 </div>
		</div>
		</div>
			  
		
		<div name="em_fcksettings" id="em_fcksettings" class="dbx-box">
		<h3 class="dbx-handle">FCKEditor Preferences</h3>
		<div class="dbx-content"><h3></h3>
			<div>
				<p><label for="em_fck_skin"><strong>Toolbar graphical skin:</strong></label> <br />
					<select name="em_fck_skin" id="em_fck_skin">
						<option value="default" <?php selected('default', get_user_option('em_user_fck_skin'));?>/>Default &nbsp;</option>
						<option value="office2003" <?php selected('office2003', get_user_option('em_user_fck_skin'));?>/>Office 2003 &nbsp;</option>
						<option value="silver" <?php selected('silver', get_user_option('em_user_fck_skin'));?>/>Silver &nbsp;</option>
					</select>
				</p>
			</div>
		</div>
		</div>
		
		</div>
		
		<br clear="all" />
		<?php
	}
}

	
	/** 
		Updates EditorMonkey user settings set from the Profile page
	*/
if (!function_exists('editormonkey_user_personalopts_update')) {
	function editormonkey_user_personalopts_update() {
		global $current_user;
		
		if ( !isset( $_POST['em_use'] ) ) {
			$_POST['em_use'] = 'false';
		} else {
			update_user_option( $current_user->id, 'rich_editing', 'false', true );
		}
			
		update_user_option( $current_user->id, 'em_user_userprefset', 'true', true );
		
		// Shared settings
		update_user_option( $current_user->id, 'em_user_use', $_POST['em_use'], true);

		update_user_option( $current_user->id, 'em_user_interface', $_POST['em_interface'], true);
		update_user_option( $current_user->id, 'em_user_height', htmlspecialchars($_POST['em_height']), true);
		update_user_option( $current_user->id, 'em_user_lang', htmlspecialchars($_POST['em_lang']), true);
		
		// FCK settings
		update_user_option( $current_user->id, 'em_user_toolbar', $_POST['em_fck_toolbar'], true);
		update_user_option( $current_user->id, 'em_user_fck_skin', $_POST['em_fck_skin'], true);
		
	}
}


/* These are helper functions, not directly involved with the editors, but with ancilliary functions
of EditorMoneky, such as the configuration interface. */
if (!function_exists('scan_plugins')) {
	function scan_plugins( ) {
		$plugins = array();
		$pluginsdir = dirname(__FILE__) .
			DIRECTORY_SEPARATOR . 'tinymce'  .
			DIRECTORY_SEPARATOR . 'plugins' . DIRECTORY_SEPARATOR; 
		$d = dir($pluginsdir);
		while (false !== ($entry = $d->read())) {
			if (is_dir($pluginsdir.$entry) && ($entry != '.') && ($entry != '..')) {
				$plugins[] = $entry;
			}
		}
		$d->close();
		$plugins[] = 'spellcheck';
		sort($plugins);
		return $plugins;
	}
}


if (!function_exists('language_selection')) {
	function language_selection ( $sel_lang ) {
	?>
		<select name="em_lang" id="em_lang">
		<optgroup label="FCKeditor and TinyMCE">
		  <option value="ar" <?php if($sel_lang=='ar') echo 'selected="selected"'; ?>>Arabic</option>
		  <option value="ca" <?php if($sel_lang=='ca') echo 'selected="selected"'; ?>>Catalan</option>
		  <option value="zh-cn" <?php if($sel_lang=='zh-cn') echo 'selected="selected"'; ?>>Chinese (Simplified)</option>
		  <option value="cs" <?php if($sel_lang=='cs') echo 'selected="selected"'; ?>>Czech</option>
		  <option value="da" <?php if($sel_lang=='da') echo 'selected="selected"'; ?>>Danish</option>
		  <option value="nl" <?php if($sel_lang=='nl') echo 'selected="selected"'; ?>>Dutch</option>
		  <option value="en" <?php if($sel_lang=='en') echo 'selected="selected"'; ?>>English</option>
		  <option value="fa" <?php if($sel_lang=='fa') echo 'selected="selected"'; ?>>Farsi/Persian</option>
		  <option value="fi" <?php if($sel_lang=='fi') echo 'selected="selected"'; ?>>Finnish</option>
		  <option value="fr" <?php if($sel_lang=='fr') echo 'selected="selected"'; ?>>French</option>
		  <option value="de" <?php if($sel_lang=='de') echo 'selected="selected"'; ?>>German</option>
		  <option value="el" <?php if($sel_lang=='el') echo 'selected="selected"'; ?>>Greek</option>
		  <option value="he" <?php if($sel_lang=='he') echo 'selected="selected"'; ?>>Hebrew</option>
		  <option value="hu" <?php if($sel_lang=='hu') echo 'selected="selected"'; ?>>Hungarian</option>
		  <option value="it" <?php if($sel_lang=='it') echo 'selected="selected"'; ?>>Italian</option>
		  <option value="ja" <?php if($sel_lang=='ja') echo 'selected="selected"'; ?>>Japanese</option>
		  <option value="ko" <?php if($sel_lang=='ko') echo 'selected="selected"'; ?>>Korean</option>
		  <option value="pl" <?php if($sel_lang=='pl') echo 'selected="selected"'; ?>>Polish</option>
		  <option value="pt" <?php if($sel_lang=='pt') echo 'selected="selected"'; ?>>Portugese</option>
		  <option value="pt-br" <?php if($sel_lang=='pt-br') echo 'selected="selected"'; ?>>Portugese (Brazilian)</option>
		  <option value="es" <?php if($sel_lang=='es') echo 'selected="selected"'; ?>>Spanish</option>
		  <option value="sv" <?php if($sel_lang=='sv') echo 'selected="selected"'; ?>>Swedish</option>
		  <option value="th" <?php if($sel_lang=='th') echo 'selected="selected"'; ?>>Thai</option>
		</optgroup>
		<optgroup label="FCKeditor Only">
		  <option value="eu" <?php if($sel_lang=='eu') echo 'selected="selected"'; ?>>Basque</option>
		  <option value="bs" <?php if($sel_lang=='bs') echo 'selected="selected"'; ?>>Bosnian</option>
		  <option value="bg" <?php if($sel_lang=='bg') echo 'selected="selected"'; ?>>Bulgarian</option>
		  <option value="zh" <?php if($sel_lang=='zh') echo 'selected="selected"'; ?>>Chinese (Traditional)</option>
		  <option value="hr" <?php if($sel_lang=='hr') echo 'selected="selected"'; ?>>Croatian</option>
		  <option value="en-au" <?php if($sel_lang=='en-au') echo 'selected="selected"'; ?>>English (Australian)</option>
		  <option value="en-uk" <?php if($sel_lang=='en-uk') echo 'selected="selected"'; ?>>English (United Kingdom)</option>
		  <option value="eo" <?php if($sel_lang=='eo') echo 'selected="selected"'; ?>>Esperanto</option>
		  <option value="et" <?php if($sel_lang=='et') echo 'selected="selected"'; ?>>Estonian</option>
		  <option value="fo" <?php if($sel_lang=='fo') echo 'selected="selected"'; ?>>Faroese</option>
		  <option value="gl" <?php if($sel_lang=='gl') echo 'selected="selected"'; ?>>Galician</option>
		  <option value="hi" <?php if($sel_lang=='hi') echo 'selected="selected"'; ?>>Hindi</option>
		  <option value="lv" <?php if($sel_lang=='lv') echo 'selected="selected"'; ?>>Latvian</option>
		  <option value="lt" <?php if($sel_lang=='lt') echo 'selected="selected"'; ?>>Lithuanian</option>
		  <option value="ms" <?php if($sel_lang=='ms') echo 'selected="selected"'; ?>>Malay</option>
		  <option value="mn" <?php if($sel_lang=='mn') echo 'selected="selected"'; ?>>Mongolian</option>
		  <option value="no" <?php if($sel_lang=='no') echo 'selected="selected"'; ?>>Norwegian</option>
		  <option value="ro" <?php if($sel_lang=='ro') echo 'selected="selected"'; ?>>Romanian</option>
		  <option value="ru" <?php if($sel_lang=='ru') echo 'selected="selected"'; ?>>Russian</option>
		  <option value="sk" <?php if($sel_lang=='sk') echo 'selected="selected"'; ?>>Slovak</option>
		  <option value="sl" <?php if($sel_lang=='sl') echo 'selected="selected"'; ?>>Slovenian</option>
		  <option value="sr" <?php if($sel_lang=='sr') echo 'selected="selected"'; ?>>Serbian (Cyrillic)</option>
		  <option value="sr-latn" <?php if($sel_lang=='sr-latn') echo 'selected="selected"'; ?>>Serbian (Latin)</option>
		  <option value="tr" <?php if($sel_lang=='tr') echo 'selected="selected"'; ?>>Turkish</option>
		  <option value="uk" <?php if($sel_lang=='uk') echo 'selected="selected"'; ?>>Ukrainian</option>
		  <option value="vi" <?php if($sel_lang=='vi') echo 'selected="selected"'; ?>>Vietnamese</option>
		</optgroup>
		<optgroup label="TinyMCE Only">
		  <option value="zh_tw_utf8" <?php if($sel_lang=='zh_tw_utf8') echo 'selected="selected"'; ?>>Chinese (Traditional)</option>
		  <option value="fr_ca" <?php if($sel_lang=='fr_ca') echo 'selected="selected"'; ?>>French (Canadian)</option>
		  <option value="is" <?php if($sel_lang=='is') echo 'selected="selected"'; ?>>Icelandic</option>
		  <option value="nb" <?php if($sel_lang=='nb') echo 'selected="selected"'; ?>>Norwegian (Bokmal)</option>
		  <option value="nn" <?php if($sel_lang=='nn') echo 'selected="selected"'; ?>>Norwegian (Nynorsk)</option>
		  <option value="cy" <?php if($sel_lang=='cy') echo 'selected="selected"'; ?>>Welsh</option>
		</optgroup>
		</select>
	<?php
	}
}

// Run it all down, baby!
editormonkey();
?>